Documentation
¶
Index ¶
- type Store
- func (s *Store) Cleanup(ctx context.Context) error
- func (s *Store) Delete(ctx context.Context, id string) error
- func (s *Store) Find(ctx context.Context, id string) (data []byte, expiry time.Time, err error)
- func (s *Store) Migrate(ctx context.Context) error
- func (s *Store) Reset(ctx context.Context) error
- func (s *Store) Upsert(ctx context.Context, id string, data []byte, expiry time.Time) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Store ¶
type Store struct {
Table string
// Used for testing
Now func() time.Time
// contains filtered or unexported fields
}
func (*Store) Find ¶
Find returns the data for a session id from the store. If the session is not found, expired or tampered, the data will be nil and the time will be zero, but there will be no error.
Click to show internal directories.
Click to hide internal directories.